Internal structure
==================

The internal structure of grogupy can be seen below. 
The graph was generated by 
`pydeps <https://pydeps.readthedocs.io/en/latest/>`_.

.. image:: dependencies.svg
